@@ -9,14 +9,17 @@ import re
 
 class GoogleQuotesReader(_BaseReader):
 
-    """Get current google quote"""
+    """Get current google quote
+       WARNING: OFFLINE AS OF OCT 1, 2017
+    """
 
     @property
     def url(self):
-        return 'http://www.google.com/finance/info'
+        return 'https://finance.google.com/finance/info'
 
     @property
     def params(self):
+        """Parameters to use in API calls"""
         if isinstance(self.symbols, pd.compat.string_types):
             sym_list = self.symbols
         else:
@@ -28,7 +31,7 @@ class GoogleQuotesReader(_BaseReader):
         buffer = out.read()
         m = re.search('// ', buffer)
         result = json.loads(buffer[m.start() + len('// '):])
-        return pd.DataFrame([[float(x['cp']), float(x['l']),
+        return pd.DataFrame([[float(x['cp']), float(x['l'].replace(',', '')),
                               np.datetime64(parse(x['lt']).isoformat())]
                              for x in result], columns=['change_pct',
                                                         'last', 'time'],
